/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CTOOLOVERVIEWGROUPBOX_H
#define CTOOLOVERVIEWGROUPBOX_H

#include "shell/CShellCmd.h"
#include "ui_IToolOverviewGroupBox.h"

class QSettings;

class CToolOverviewGroupBox : public QGroupBox, private Ui::IToolOverviewGroupBox {
  Q_OBJECT
 public:
  CToolOverviewGroupBox(QWidget* parent);
  virtual ~CToolOverviewGroupBox() = default;

  void saveSettings(QSettings& cfg);
  void loadSettings(QSettings& cfg);

  void buildCmd(QList<CShellCmd>& cmds, const QString& filename, const QString& resampling);
};

#endif  // CTOOLOVERVIEWGROUPBOX_H
